@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifndef _MAILUTILS_HEADER_H
 #define _MAILUTILS_HEADER_H
@@ -59,6 +60,7 @@ extern "C" {
 #define MU_HEADER_CONTENT_DISPOSITION       "Content-Disposition"
 #define MU_HEADER_CONTENT_MD5               "Content-MD5"
 #define MU_HEADER_MIME_VERSION              "MIME-Version"
+#define MU_HEADER_X_MAILER                  "X-Mailer"
 #define MU_HEADER_X_UIDL                    "X-UIDL"
 #define MU_HEADER_X_UID                     "X-UID"
 #define MU_HEADER_X_IMAPBASE                "X-IMAPbase"
@@ -71,78 +73,65 @@ extern "C" {
   
 /* Mime support header attribute */
 
-extern int header_create __P ((header_t *, const char *, size_t, void *));
-extern void header_destroy __P ((header_t *, void *));
-extern void *header_get_owner __P ((header_t));
+extern int mu_header_create (mu_header_t *, const char *, size_t, void *);
+extern void mu_header_destroy (mu_header_t *, void *);
+extern void *mu_header_get_owner (mu_header_t);
 
-extern int header_is_modified __P ((header_t));
-extern int header_clear_modified __P ((header_t));
+extern int mu_header_is_modified (mu_header_t);
+extern int mu_header_clear_modified (mu_header_t);
 
 /* Set and get field values by field name. */
-extern int header_set_value __P ((header_t, const char *, const char *, int));
-extern int header_get_value __P ((header_t, const char *, char *, size_t, size_t *));
-extern int header_aget_value __P ((header_t, const char *, char **));
+extern int mu_header_set_value (mu_header_t, const char *, const char *, int);
+extern int mu_header_get_value (mu_header_t, const char *, char *, size_t, size_t *);
+extern int mu_header_aget_value (mu_header_t, const char *, char **);
 
-/* Get field values as an address_t. */
-extern int header_get_address __P ((header_t, const char *, address_t *));
+/* Get field values as an mu_address_t. */
+extern int mu_header_get_address (mu_header_t, const char *, mu_address_t *);
 
 /* Set and get field values by field index (1-based). */
-extern int header_get_field_count __P ((header_t, size_t *count));
-extern int header_get_field_value __P ((header_t, size_t index, char *, size_t, size_t *));
-extern int header_get_field_name __P ((header_t, size_t index, char *, size_t, size_t *));
-extern int header_aget_field_value __P ((header_t, size_t index, char **));
-extern int header_aget_field_name __P ((header_t, size_t index, char **));
+extern int mu_header_get_field_count (mu_header_t, size_t *count);
+extern int mu_header_get_field_value (mu_header_t, size_t index, char *, size_t, size_t *);
+extern int mu_header_get_field_name (mu_header_t, size_t index, char *, size_t, size_t *);
+extern int mu_header_aget_field_value (mu_header_t, size_t index, char **);
+extern int mu_header_aget_field_name (mu_header_t, size_t index, char **);
 
-extern int header_get_value_unfold __P((header_t header, const char *name,
-					char *buffer, size_t buflen,
-					size_t *pn));
-extern int header_aget_value_unfold __P((header_t header, const char *name,
-					 char **pvalue));
-extern int header_get_field_value_unfold __P((header_t header, size_t num,
-					      char *buf, size_t buflen,
-					      size_t *nwritten));
-extern int header_aget_field_value_unfold __P((header_t header, size_t num,
-					       char **pvalue));
+extern int mu_header_get_value_unfold (mu_header_t header, const char *name,
+			  	    char *buffer, size_t buflen,
+				    size_t *pn);
+extern int mu_header_aget_value_unfold (mu_header_t header, const char *name,
+				     char **pvalue);
+extern int mu_header_get_field_value_unfold (mu_header_t header, size_t num,
+					  char *buf, size_t buflen,
+					  size_t *nwritten);
+extern int mu_header_aget_field_value_unfold (mu_header_t header, size_t num,
+					   char **pvalue);
 
-extern int header_get_stream __P ((header_t, stream_t *));
-extern int header_set_stream __P ((header_t, stream_t, void *));
+extern int mu_header_get_stream (mu_header_t, mu_stream_t *);
+extern int mu_header_set_stream (mu_header_t, mu_stream_t, void *);
 
-extern int header_size __P ((header_t, size_t *));
-extern int header_lines __P ((header_t, size_t *));
+extern int mu_header_size (mu_header_t, size_t *);
+extern int mu_header_lines (mu_header_t, size_t *);
 
 
-extern int header_set_set_value __P ((header_t,
-				      int (*_set_value) __PMT ((header_t,
-							        const char *,
-							        const char *,
-							        int)), void *));
+extern int mu_header_set_set_value (mu_header_t,
+	      int (*_set_value) (mu_header_t, const char *, const char *, int), 
+              void *);
 
-extern int header_set_get_value __P ((header_t,
-				      int (*_get_value) __PMT ((header_t,
-							        const char *,
-							        char *,
-							        size_t,
-							        size_t *)),
-				      void *));
-extern int header_set_get_fvalue __P ((header_t,
-				       int (*_get_value) __PMT ((header_t,
-							         const char *,
-							         char *,
-							         size_t,
-							         size_t *)),
-				       void *));
+extern int mu_header_set_get_value (mu_header_t,
+      int (*_get_value) (mu_header_t, const char *, char *, size_t, size_t *),
+				 void *);
+extern int mu_header_set_get_fvalue (mu_header_t,
+      int (*_get_value) (mu_header_t, const char *, char *, size_t, size_t *),
+				       void *);
 
-extern int header_set_size __P ((header_t, int (*_size)
-				 __PMT ((header_t, size_t *)), void *));
+extern int mu_header_set_size (mu_header_t, 
+      int (*_size) (mu_header_t, size_t *), void *);
 
-extern int header_set_lines __P ((header_t,
-				  int (*_lines) __PMT ((header_t,
-						        size_t *)), void *));
+extern int mu_header_set_lines (mu_header_t,
+      int (*_lines) (mu_header_t, size_t *), void *);
 
-extern int header_set_fill __P ((header_t,
-				 int (*_fill) __PMT ((header_t, char *,
-						      size_t, off_t,
-						      size_t *)), void *owner));
+extern int mu_header_set_fill (mu_header_t,
+      int (*_fill) (mu_header_t, char *, size_t, mu_off_t, size_t *), void *owner);
 
   
 #ifdef __cplusplus
