@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2005, 2006  Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -50,7 +50,9 @@
 extern "C" {
 #endif
 
-extern void mu_init_nls __P((void));
+extern void mu_init_nls (void);
+extern char *mu_set_locale (const char *locale);
+void mu_restore_locale (void);
 
 #ifdef __cplusplus
 }
