@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2004, 
+   2005 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -30,7 +31,7 @@ sieve_code (sieve_op_t *op)
   if (sieve_machine->pc >= sieve_machine->progsize)
     {
       size_t newsize = sieve_machine->progsize + SIEVE_CODE_INCR;
-      sieve_op_t *newprog = sieve_mrealloc (sieve_machine, sieve_machine->prog,
+      sieve_op_t *newprog = mu_sieve_mrealloc (sieve_machine, sieve_machine->prog,
 					    newsize *
 					    sizeof sieve_machine->prog[0]);
       if (!newprog)
@@ -56,7 +57,7 @@ sieve_code_instr (sieve_instr_t instr)
 }
 
 int
-sieve_code_handler (sieve_handler_t handler)
+sieve_code_handler (mu_sieve_handler_t handler)
 {
   sieve_op_t op;
 
@@ -65,7 +66,7 @@ sieve_code_handler (sieve_handler_t handler)
 }
 
 int
-sieve_code_list (list_t list)
+sieve_code_list (mu_list_t list)
 {
   sieve_op_t op;
 
@@ -91,9 +92,9 @@ sieve_code_string (char *string)
   return sieve_code (&op);
 }
 
-sieve_tag_def_t *
-find_tag (sieve_tag_group_t *taglist, char *tagname,
-	  sieve_tag_checker_t *checker)
+mu_sieve_tag_def_t *
+find_tag (mu_sieve_tag_group_t *taglist, char *tagname,
+	  mu_sieve_tag_checker_t *checker)
 {
   *checker = NULL;
   
@@ -102,7 +103,7 @@ find_tag (sieve_tag_group_t *taglist, char *tagname,
   
   for (; taglist->tags; taglist++)
     {
-      sieve_tag_def_t *def;
+      mu_sieve_tag_def_t *def;
       for (def = taglist->tags; def->name; def++)
 	if (strcmp (def->name, tagname) == 0)
 	  {
@@ -121,27 +122,27 @@ _compare_ptr (void *item, void *data)
 
 struct check_arg {
   const char *name;
-  list_t args;
-  list_t tags;
+  mu_list_t args;
+  mu_list_t tags;
 };
 
 static int
 _run_checker (void *item, void *data)
 {
   struct check_arg *arg = data;
-  return (*(sieve_tag_checker_t)item) (arg->name, arg->tags, arg->args);
+  return (*(mu_sieve_tag_checker_t)item) (arg->name, arg->tags, arg->args);
 }
 
 int
-sieve_code_command (sieve_register_t *reg, list_t arglist)
+sieve_code_command (mu_sieve_register_t *reg, mu_list_t arglist)
 {
-  iterator_t itr;
-  list_t arg_list = NULL;
-  list_t tag_list = NULL;
-  list_t chk_list = NULL;
-  sieve_data_type *exp_arg;
+  mu_iterator_t itr;
+  mu_list_t arg_list = NULL;
+  mu_list_t tag_list = NULL;
+  mu_list_t chk_list = NULL;
+  mu_sieve_data_type *exp_arg;
   int rc, err = 0;
-  static sieve_data_type empty[] = { SVT_VOID };
+  static mu_sieve_data_type empty[] = { SVT_VOID };
   
   if (sieve_code_handler (reg->handler))
     return 1;
@@ -150,7 +151,7 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 
   if (arglist)
     {
-      rc = list_get_iterator (arglist, &itr);
+      rc = mu_list_get_iterator (arglist, &itr);
 
       if (rc)
 	{
@@ -160,17 +161,17 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 	  return 1;
 	}
   
-      for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
+      for (mu_iterator_first (itr); !mu_iterator_is_done (itr); mu_iterator_next (itr))
 	{
-	  sieve_value_t *val;
-	  sieve_runtime_tag_t tagrec, *tagptr;
+	  mu_sieve_value_t *val;
+	  mu_sieve_runtime_tag_t tagrec, *tagptr;
 	  
-	  iterator_current (itr, (void **)&val);
+	  mu_iterator_current (itr, (void **)&val);
 	  
 	  if (val->type == SVT_TAG)
 	    {
-	      sieve_tag_checker_t cf;
-	      sieve_tag_def_t *tag = find_tag (reg->tags, val->v.string, &cf);
+	      mu_sieve_tag_checker_t cf;
+	      mu_sieve_tag_def_t *tag = find_tag (reg->tags, val->v.string, &cf);
 	      if (!tag)
 		{
 		  sieve_compile_error (sieve_filename, sieve_line_num,
@@ -180,7 +181,7 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 		  break;
 		}
 	      
-	      if (!tag_list && (rc = list_create (&tag_list)))
+	      if (!tag_list && (rc = mu_list_create (&tag_list)))
 		{
 		  sieve_compile_error (sieve_filename, sieve_line_num,
                                        _("%s:%d: cannot create tag list: %s"),
@@ -192,19 +193,19 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 	      tagrec.tag = tag->name;
 	      if (tag->argtype != SVT_VOID)
 		{
-		  iterator_next (itr);
-		  iterator_current (itr, (void **)&tagrec.arg);
+		  mu_iterator_next (itr);
+		  mu_iterator_current (itr, (void **)&tagrec.arg);
 		}
 	      else
 		tagrec.arg = NULL;
 	      
-	      tagptr = sieve_malloc (sieve_machine, sizeof (*tagptr));
+	      tagptr = mu_sieve_malloc (sieve_machine, sizeof (*tagptr));
 	      *tagptr = tagrec;
-	      list_append (tag_list, tagptr);
+	      mu_list_append (tag_list, tagptr);
 
 	      if (cf)
 		{
-		  if (!chk_list && (rc = list_create (&chk_list)))
+		  if (!chk_list && (rc = mu_list_create (&chk_list)))
 		    {
 		      sieve_compile_error (sieve_filename, sieve_line_num,
 			  	         _("%s:%d: cannot create check list: %s"),
@@ -212,8 +213,8 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 		      err = 1;
 		      break;
 		    }
-		  if (list_do (chk_list, _compare_ptr, cf) == 0)
-		    list_append (chk_list, cf);
+		  if (mu_list_do (chk_list, _compare_ptr, cf) == 0)
+		    mu_list_append (chk_list, cf);
 		}
 	    }
 	  else if (*exp_arg == SVT_VOID)
@@ -230,12 +231,12 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 		{
 		  if (*exp_arg == SVT_STRING_LIST && val->type == SVT_STRING)
 		    {
-		      list_t list;
+		      mu_list_t list;
 
-		      list_create (&list);
-		      list_append (list, val->v.string);
-		      sieve_mfree (sieve_machine, val);
-		      val = sieve_value_create (SVT_STRING_LIST, list);
+		      mu_list_create (&list);
+		      mu_list_append (list, val->v.string);
+		      mu_sieve_mfree (sieve_machine, val);
+		      val = mu_sieve_value_create (SVT_STRING_LIST, list);
 		    }
 		  else
 		    {
@@ -245,14 +246,14 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 				      reg->name);
 		      sieve_compile_error (sieve_filename, sieve_line_num,
 					   _("expected %s but passed %s"),
-					   sieve_type_str (*exp_arg),
-					   sieve_type_str (val->type));
+					   mu_sieve_type_str (*exp_arg),
+					   mu_sieve_type_str (val->type));
 		      err = 1;
 		      break;
 		    }
 		}
 
-	      if (!arg_list && (rc = list_create (&arg_list)))
+	      if (!arg_list && (rc = mu_list_create (&arg_list)))
 		{
 		  sieve_compile_error (sieve_filename, sieve_line_num,
                                        _("cannot create arg list: %s"),
@@ -261,11 +262,11 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 		  break;
 		}
 	      
-	      list_append (arg_list, val);
+	      mu_list_append (arg_list, val);
 	      exp_arg++;
 	    }	    
 	}
-      iterator_destroy (&itr);
+      mu_iterator_destroy (&itr);
     }
 
   if (!err)
@@ -285,7 +286,7 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 	  chk_arg.name = reg->name;
 	  chk_arg.tags = tag_list;
 	  chk_arg.args = arg_list;
-	  err = list_do (chk_list, _run_checker, &chk_arg);
+	  err = mu_list_do (chk_list, _run_checker, &chk_arg);
 	}
     }
   
@@ -296,9 +297,9 @@ sieve_code_command (sieve_register_t *reg, list_t arglist)
 
   if (err)
     {
-      list_destroy (&arg_list);
-      list_destroy (&tag_list);
-      list_destroy (&chk_list);
+      mu_list_destroy (&arg_list);
+      mu_list_destroy (&tag_list);
+      mu_list_destroy (&chk_list);
     }
 
   return err;
@@ -309,10 +310,10 @@ sieve_code_source (const char *name)
 {
   char *s;
   
-  if (list_locate (sieve_machine->source_list, (void*) name, (void **) &s))
+  if (mu_list_locate (sieve_machine->source_list, (void*) name, (void **) &s))
     {
-      s = sieve_mstrdup (sieve_machine, name);
-      list_append (sieve_machine->source_list, s);
+      s = mu_sieve_mstrdup (sieve_machine, name);
+      mu_list_append (sieve_machine->source_list, s);
     }
   
   return sieve_code_instr (instr_source)
@@ -329,18 +330,39 @@ sieve_code_line (size_t line)
 	 || sieve_code (&op);
 }
 
-int
-sieve_code_action (sieve_register_t *reg, list_t arglist)
+static int sieve_source_changed;
+
+void
+sieve_change_source ()
 {
-  return sieve_code_line (sieve_line_num)
+  sieve_source_changed = 1;
+}
+
+static int
+sieve_check_source_changed ()
+{
+  if (sieve_source_changed)
+    {
+      sieve_source_changed = 0;
+      return sieve_code_source (sieve_filename);
+    }
+  return 0;
+}
+
+int
+sieve_code_action (mu_sieve_register_t *reg, mu_list_t arglist)
+{
+  return sieve_check_source_changed ()
+         || sieve_code_line (sieve_line_num)
          || sieve_code_instr (instr_action)
          || sieve_code_command (reg, arglist);
 }
 
 int
-sieve_code_test (sieve_register_t *reg, list_t arglist)
+sieve_code_test (mu_sieve_register_t *reg, mu_list_t arglist)
 {
-  return sieve_code_line (sieve_line_num)
+  return sieve_check_source_changed ()
+         || sieve_code_line (sieve_line_num)
          || sieve_code_instr (instr_test)
          || sieve_code_command (reg, arglist);
 }
