@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 
 #include <mh.h>
 
-typedef int (*handler_fp) __PMT((struct mh_whatnow_env *wh,
-				 int argc, char **argv,
-				 int *status));
+typedef int (*handler_fp) (struct mh_whatnow_env *wh,
+			   int argc, char **argv,
+			   int *status);
 
 /* ********************* Auxiliary functions *********************** */
 /* Auxiliary function for option comparisons */
@@ -55,7 +55,7 @@ func (struct action_tab *p, const char *name)
 	return p->fp;
     }
 
-  mh_error (_("%s is unknown. Hit <CR> for help"), name);
+  mu_error (_("%s is unknown. Hit <CR> for help"), name);
   return NULL;
 }
 
@@ -186,44 +186,66 @@ display_file (const char *name)
     mh_spawnp (pager, name);
   else
     {
-      stream_t stream;
+      mu_stream_t stream;
       int rc;
       size_t off = 0;
       size_t n;
       char buffer[512];
       
-      rc = file_stream_create (&stream, name, MU_STREAM_READ);
+      rc = mu_file_stream_create (&stream, name, MU_STREAM_READ);
       if (rc)
 	{
-	  mh_error ("file_stream_create: %s", mu_strerror (rc));
+	  mu_error ("mu_file_stream_create: %s", mu_strerror (rc));
 	  return;
 	}
-      rc = stream_open (stream);
+      rc = mu_stream_open (stream);
       if (rc)
 	{
-	  mh_error ("stream_open: %s", mu_strerror (rc));
+	  mu_error ("mu_stream_open: %s", mu_strerror (rc));
 	  return;
 	} 
       
-      while (stream_read (stream, buffer, sizeof buffer - 1, off, &n) == 0
+      while (mu_stream_read (stream, buffer, sizeof buffer - 1, off, &n) == 0
 	     && n != 0)
 	{
 	  buffer[n] = '\0';
 	  printf ("%s", buffer);
 	  off += n;
 	}
-      stream_destroy (&stream, NULL);
+      mu_stream_destroy (&stream, NULL);
     }
 }      
 
+static int
+check_exit_status (char *progname, int status)
+{
+  if (WIFEXITED (status))
+    {
+      if (WEXITSTATUS (status))
+	{
+	  mu_error (_("Command `%s' exited with status %d"),
+		    progname, WEXITSTATUS(status));
+	  return 1;
+	}
+      return 0;
+    }
+  else if (WIFSIGNALED (status))
+    mu_error (_("Command `%s' terminated on signal %d"),
+	      progname, WTERMSIG (status));
+  else
+    mu_error (_("Command `%s' terminated abnormally"), progname);
+  return 1;
+}
+
 static int
 invoke (char *compname, char *defval, int argc, char **argv,
-	char *extra0, char *extra1, int *status)
+	char *extra0, char *extra1)
 {
   int i, rc;
   char **xargv;
   char *progname;
-
+  int status;
+  
   progname = mh_global_profile_get (compname, defval);
   if (!progname)
     return -1;
@@ -243,9 +265,63 @@ invoke (char *compname, char *defval, int argc, char **argv,
   if (extra1)
     xargv[i++] = extra1;
   xargv[i++] = NULL;
-  rc = mu_spawnvp (xargv[0], (const char **) xargv, status);
+  rc = mu_spawnvp (xargv[0], (const char **) xargv, &status);
   free (xargv);
-  return rc;
+  return rc ? rc : check_exit_status (progname, status);
+}
+
+struct anno_data
+{
+  char *field;
+  char *value;
+  int date;
+};
+
+static int
+anno (void *item, void *data)
+{
+  struct anno_data *d = item; 
+  mh_annotate (item, d->field, d->value, d->date);
+  return 0;
+}
+
+static void
+annotate (struct mh_whatnow_env *wh)
+{
+  mu_message_t msg;
+  mu_address_t addr = NULL;
+  size_t i, count;
+  
+  if (!wh->anno_field || !wh->anno_list)
+    return;
+  
+  msg = mh_file_to_message (NULL, wh->file);
+  if (!msg)
+    return;
+  
+  mh_expand_aliases (msg, &addr, NULL, NULL);
+  mu_address_get_count (addr, &count);
+  for (i = 1; i <= count; i++)
+    {
+      mu_address_t subaddr;
+
+      if (mu_address_get_nth (addr, i, &subaddr) == 0)
+	{
+	  size_t size;
+	  struct anno_data d;
+
+	  mu_address_to_string (subaddr, NULL, 0, &size);
+	  d.value = xmalloc (size + 1);
+	  d.field = wh->anno_field;
+	  d.date = i == 1;
+	  mu_address_to_string (subaddr, d.value, size + 1, NULL);
+	  mu_list_do (wh->anno_list, anno, &d);
+	  free (d.value);
+	  mu_address_destroy (&subaddr);
+	}
+    }
+  mu_address_destroy (&addr);
+  mu_message_destroy (&msg, NULL);
 }
 
 
@@ -268,11 +344,11 @@ _whatnow (struct mh_whatnow_env *wh, struct action_tab *tab)
       getline (&line, &size, stdin);
       if (!line)
 	continue;
-      rc = argcv_get (line, "", "#", &argc, &argv);
+      rc = mu_argcv_get (line, "", "#", &argc, &argv);
       free (line);
       if (rc)
 	{
-	  argcv_free (argc, argv);
+	  mu_argcv_free (argc, argv);
 	  break;
 	}
 
@@ -281,7 +357,7 @@ _whatnow (struct mh_whatnow_env *wh, struct action_tab *tab)
 	rc = fun (wh, argc, argv, &status);
       else
 	rc = 0;
-      argcv_free (argc, argv);
+      mu_argcv_free (argc, argv);
     }
   while (rc == 0);
   return status;
@@ -295,7 +371,7 @@ static int
 display (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 {
   if (!wh->msg)
-    mh_error (_("no alternate message to display"));
+    mu_error (_("no alternate message to display"));
   else
     display_file (wh->msg);
   return 0;
@@ -306,10 +382,9 @@ static int
 edit (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 {
   char *name;
-  int rc;
   
   asprintf (&name, "%s-next", wh->editor);
-  invoke (name, wh->editor, argc, argv, wh->file, NULL, &rc);
+  invoke (name, wh->editor, argc, argv, wh->file, NULL);
   free (name);
   
   return 0;
@@ -320,7 +395,7 @@ static int
 list (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 {
   if (!wh->file)
-    mh_error (_("no draft file to display"));
+    mu_error (_("no draft file to display"));
   else
     display_file (wh->file);
   return 0;
@@ -330,8 +405,8 @@ list (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 static int
 push (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 {
-  int rc;
-  invoke ("sendproc", MHBINDIR "/send", argc, argv, "-push", wh->file, &rc);
+  if (invoke ("sendproc", MHBINDIR "/send", argc, argv, "-push", wh->file) == 0)
+    annotate (wh);
   return 0;
 }
 
@@ -348,7 +423,8 @@ quit (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
       else
 	{
 	  printf (_("draft left on \"%s\".\n"), wh->draftfile);
-	  rename (wh->file, wh->draftfile);
+	  if (strcmp (wh->file, wh->draftfile))
+	    rename (wh->file, wh->draftfile);
 	}
     }
 
@@ -359,8 +435,7 @@ quit (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 static int
 refile (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 {
-  int rc;
-  invoke ("fileproc", MHBINDIR "/refile", argc, argv, "-file", wh->file, &rc);
+  invoke ("fileproc", MHBINDIR "/refile", argc, argv, "-file", wh->file);
   return 0;
 }
 
@@ -368,8 +443,8 @@ refile (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 static int
 send (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 {
-  int rc;
-  invoke ("sendproc", MHBINDIR "/send", argc, argv, wh->file, NULL, &rc);
+  if (invoke ("sendproc", MHBINDIR "/send", argc, argv, wh->file, NULL) == 0)
+    annotate (wh);
   return 0;
 }
 
@@ -378,7 +453,7 @@ static int
 whom (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 {
   if (!wh->file)
-    mh_error (_("no draft file to display"));
+    mu_error (_("no draft file to display"));
   else
     mh_whom (wh->file, (argc == 2
 			&& (strcmp (argv[1], "-check") == 0
@@ -475,7 +550,13 @@ int
 mh_whatnow (struct mh_whatnow_env *wh, int initial_edit)
 {
   if (!wh->editor)
-    wh->editor = mh_global_profile_get ("Editor", "prompter");
+    {
+      char *p;
+      wh->editor = mh_global_profile_get ("Editor",
+					  (p = getenv ("VISUAL")) ?
+					    p : (p = (getenv ("EDITOR"))) ?
+					          p : "prompter");	  
+    }
   
   if (initial_edit)
     mh_spawnp (wh->editor, wh->file);
